@@ -5,9 +5,10 @@
 
 
 # test of Wendland covariance and  stationary.taper.cov
-# test.for.zero.flag<- 1
+
 library( fields)
 options( echo=FALSE)
+ test.for.zero.flag<- 1
 
 set.seed(123)
 x1<- matrix( runif(2*20), ncol=2)
@@ -31,7 +32,7 @@ test.for.zero( temp, temp2)
 # and also versions of Wendland function
 # default taper is wendland k=2.
 DD<- rdist( x1,x2)
-temp<- wendland2.2(DD, theta=.8)
+temp<- Wendland2.2(DD, theta=.8)
 temp2<- Wendland( DD, theta=.8, k=2, dimension=2)
 
 test.for.zero( temp, temp2)
@@ -39,11 +40,11 @@ test.for.zero( temp, temp2)
 
 
 
-stationary.taper.cov( x1,x2, Taper="wendland2.2", 
+stationary.taper.cov( x1,x2, Taper="Wendland2.2", 
            Taper.args= list( theta=.8), spam.format=FALSE )-> look
 temp0<- look
 
-stationary.taper.cov( x1,x2, Taper="wendland2.2",
+stationary.taper.cov( x1,x2, Taper="Wendland2.2",
            Taper.args= list( theta=.8), spam.format=TRUE )-> look
 temp1<-  spam2full( look)
 
@@ -55,7 +56,7 @@ stationary.taper.cov( x1,x2, Taper="Wendland",
 temp1b<-  spam2full( look)
 
 
-temp2<-  wendland2.2(DD, theta=.8) * Exponential(DD)
+temp2<-  Wendland2.2(DD, theta=.8) * Exponential(DD)
 temp3<-  wendland.cov(x1,x2, k=2, theta=.8) * Exponential(DD)
 temp4<-  Wendland(DD, k=2, dimension=2, theta=.8)* Exponential(DD)
 
@@ -76,7 +77,10 @@ rv<- runif( nrow(x2))
 stationary.taper.cov( x1, x2,  C= rv)-> look
 temp2<-stationary.taper.cov( x1,x2)
 
-spam2full(temp2)%*%(rv)-> look2
+(as.matrix(temp2))%*%(rv)-> look2
+test.for.zero( look, look2)
+
+temp2%*%(rv)-> look2
 test.for.zero( look, look2)
 
 cat( "Done with testing Wendland family", fill=TRUE)
